# Define pkgdocdir for releases that don't define it already
%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

# determine whether to install systemd or sysvinit scripts
%if 0%{?fedora} || 0%{?rhel} >= 7

%global _use_sysvinit 0
%global _use_systemd 1

%else

%global _use_sysvinit 1
%global _use_systemd 0

%endif

%global proton_minimum_version 0.24.0
%global libwebsockets_minimum_version 2.4.2

Name:          qpid-dispatch
Version:       1.2.0
Release:       9%{?dist}
Summary:       Dispatch router for Qpid
License:       ASL 2.0
URL:           http://qpid.apache.org/
Source0:       http://www.apache.org/dist/qpid/dispatch/%{version}/qpid-dispatch-%{version}.tar.gz

Source2:       licenses.xml
Source3:       qpid-dispatch-console-%{version}.tar.gz

%global _pkglicensedir %{_licensedir}/%{name}-%{version}
%{!?_licensedir:%global license %doc}
%{!?_licensedir:%global _pkglicensedir %{_pkgdocdir}}

%if 0%{?rhel} && 0%{?rhel} >= 7
ExcludeArch: i686
%endif

%if 0%{?rhel} && 0%{?rhel} <= 6
Source1:       docs-%{version}-1.tar.gz
%endif

Patch3:        dispatch.patch
Patch4:        console-listener.patch
Patch5:        console-branding.patch
Patch6:        console.patch
Patch7:        rel-1.2.2.patch

BuildRequires: qpid-proton-c-devel >= %{proton_minimum_version}
BuildRequires: python-devel
BuildRequires: cmake
BuildRequires: python-qpid-proton >= %{proton_minimum_version}
BuildRequires: openssl-devel
BuildRequires: libwebsockets-devel >= %{libwebsockets_minimum_version}

# Missing dependency on RHEL 6: asciidoc >= 8.6.8
# asciidoc-8.4.5-4.1.el6 does not work for man pages
%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
BuildRequires: asciidoc >= 8.6.8
BuildRequires: systemd
%endif


%description
A lightweight message router, written in C and built on Qpid Proton, that provides flexible and scalable interconnect between AMQP endpoints or between endpoints and brokers.


%package router
Summary:  The Qpid Dispatch Router executable
Obsoletes: libqpid-dispatch
Obsoletes: libqpid-dispatch-devel
Requires:  qpid-proton-c%{?_isa} >= %{proton_minimum_version}
Requires:  python
Requires:  python-qpid-proton >= %{proton_minimum_version}
%if %{_use_systemd}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%endif
Requires: libwebsockets >= %{libwebsockets_minimum_version}

%description router
%{summary}.


%files router
%license %{_pkglicensedir}/LICENSE
%license %{_pkglicensedir}/licenses.xml
%{_sbindir}/qdrouterd
%config(noreplace) %{_sysconfdir}/qpid-dispatch/qdrouterd.conf
%config(noreplace) %{_sysconfdir}/sasl2/qdrouterd.conf
%{_exec_prefix}/lib/qpid-dispatch
#%exclude %{_exec_prefix}/lib/qpid-dispatch/tests
%{python_sitelib}/qpid_dispatch_site.py*
%{python_sitelib}/qpid_dispatch
   
%if "%{python_version}" >= "2.6"
%{python_sitelib}/qpid_dispatch-*.egg-info
%endif

%if %{_use_systemd}

%{_unitdir}/qdrouterd.service

%else

%{_initrddir}/qdrouterd
%attr(755,qdrouterd,qdrouterd) %dir %{_localstatedir}/run/qpid-dispatch

%endif

%{_mandir}/man5/qdrouterd.conf.5*
%{_mandir}/man8/qdrouterd.8*

%pre router
getent group qdrouterd >/dev/null || groupadd -r qdrouterd
getent passwd qdrouterd >/dev/null || \
  useradd -r -M -g qdrouterd -d %{_localstatedir}/lib/qdrouterd -s /sbin/nologin \
    -c "Owner of Qdrouterd Daemons" qdrouterd
exit 0


%if %{_use_systemd}

%post router
/sbin/ldconfig
%systemd_post qdrouterd.service

%preun router
%systemd_preun qdrouterd.service

%postun router
/sbin/ldconfig
%systemd_postun_with_restart qdrouterd.service

%endif

%if %{_use_sysvinit}

%post router
/sbin/ldconfig
/sbin/chkconfig --add qdrouterd

%preun router
if [ $1 -eq 0 ]; then
    /sbin/service qdrouterd stop >/dev/null 2>&1
    /sbin/chkconfig --del qdrouterd
fi

%postun router
/sbin/ldconfig
if [ "$1" -ge "1" ]; then
    /sbin/service qdrouterd condrestart >/dev/null 2>&1
fi

%endif


%package docs
Summary:   Documentation for the Qpid Dispatch router
BuildArch: noarch
Obsoletes:  qpid-dispatch-router-docs

%description docs
%{summary}.


%files docs
%doc %{_pkgdocdir}
%license %{_pkglicensedir}/LICENSE
%license %{_pkglicensedir}/licenses.xml


%package console
Summary: Web console for Qpid Dispatch Router
BuildArch: noarch
Requires: qpid-dispatch-router

%description console
%{summary}.

%files console
%{_datarootdir}/qpid-dispatch/console


%package tools
Summary: Tools for the Qpid Dispatch router
BuildArch: noarch
Requires: python-qpid-proton >= %{proton_minimum_version}


%description tools
%{summary}.


%files tools
%{_bindir}/qdstat
%{_bindir}/qdmanage

%{_mandir}/man8/qdstat.8*
%{_mandir}/man8/qdmanage.8*


%prep
%setup -q

%patch3 -p1
%patch4 -p1
%patch7 -p1

mkdir pre_built
cd pre_built
tar xvzpf %{SOURCE3} -C .
%patch5 -p1
%patch6 -p1
%if 0%{?rhel} && 0%{?rhel} <= 6
tar xvzpf %{SOURCE1} -C .
%endif

%build
export DOCS=ON
%if 0%{?rhel} && 0%{?rhel} <= 6
export DOCS=OFF
%endif
%cmake -DDOC_INSTALL_DIR=%{?_pkgdocdir} \
       -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DUSE_SETUP_PY=0 \
       -DQD_DOC_INSTALL_DIR=%{_pkgdocdir} \
       "-DBUILD_DOCS=$DOCS" \
       -DCMAKE_SKIP_RPATH:BOOL=OFF \
       -DUSE_LIBWEBSOCKETS=ON \
       -DCONSOLE_INSTALL=OFF \
       .
make doc


%install
%make_install

%if %{_use_systemd}

install -dm 755 %{buildroot}%{_unitdir}
install -pm 644 %{_builddir}/qpid-dispatch-%{version}/etc/fedora/qdrouterd.service \
                %{buildroot}%{_unitdir}

%else

install -dm 755 %{buildroot}%{_initrddir}
install -pm 755 %{_builddir}/qpid-dispatch-%{version}/etc/fedora/qdrouterd \
                %{buildroot}%{_initrddir}

%endif

%if 0%{?rhel} && 0%{?rhel} <= 6
install -dm 755 %{buildroot}%{_mandir}/man5
install -dm 755 %{buildroot}%{_mandir}/man8
install -pm 644 %{_builddir}/qpid-dispatch-%{version}/pre_built/man/man5/* %{buildroot}%{_mandir}/man5/
install -pm 644 %{_builddir}/qpid-dispatch-%{version}/pre_built/man/man8/* %{buildroot}%{_mandir}/man8/
cp -a           %{_builddir}/qpid-dispatch-%{version}/pre_built/doc/qpid-dispatch-%{version}/*  \
                %{buildroot}%{_pkgdocdir}/
%endif

install -dm 755 %{buildroot}/var/run/qpid-dispatch

%if 0%{?rhel} && 0%{?rhel} <= 6
install -pm 644 %{SOURCE2} %{buildroot}%{_pkgdocdir}
%else
install -dm 755 %{buildroot}%{_pkglicensedir}
install -pm 644 %{SOURCE2} %{buildroot}%{_pkglicensedir}
install -pm 644 %{buildroot}%{_pkgdocdir}/LICENSE %{buildroot}%{_pkglicensedir}
rm -f %{buildroot}%{_pkgdocdir}/LICENSE
%endif

install -dm 755 %{buildroot}/%{_datarootdir}/qpid-dispatch/console
cp -a %{_builddir}/qpid-dispatch-%{version}/pre_built/console/* %{buildroot}/%{_datarootdir}/qpid-dispatch/console/

rm -f  %{buildroot}/%{_includedir}/qpid/dispatch.h
rm -fr %{buildroot}/%{_includedir}/qpid/dispatch

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%changelog
* Fri Oct 26 2018 Ted Ross <tross@redhat.com> - 1.2.0-9
- Fixed ENTMQIC-2081, ENTMQIC-2082, and ENTMQIC-2083

* Tue Oct 2 2018 Ted Ross <tross@redhat.com> - 1.2.0-8
- Added all-arch support
- Fixed ENTMQIC-2073

* Wed Sep 12 2018 Ted Ross <tross@redhat.com> - 1.2.0-7
- Branded the console for Red Hat AMQ Interconnect
- Fixed DISPATCH-1109

* Fri Aug 10 2018 Ted Ross <tross@redhat.com> - 1.2.0-6
- Added Console RPM

* Thu Jul 19 2018 Ted Ross <tross@redhat.com> - 1.2.0-5
- Fixed regression from ENTMQIC-2023

* Wed Jul 11 2018 Ted Ross <tross@redhat.com> - 1.2.0-3
- Added fixes for ENTMQIC-2023 and ENTMQIC-2004

* Fri Jul  6 2018 Irina Boverman <iboverma@redhat.com> - 1.2.0-2
- Rebuilt against proton 0.24.0

* Tue Jul  3 2018 Ted Ross <tross@redhat.com> - 1.2.0-1
- AMQ Interconnect 1.2.0.CR2 - rebase to upstream 1.2.0

* Tue Jun  12 2018 Ted Ross <tross@redhat.com> - 1.1.0-1
- AMQ Interconnect 1.2.CR1 - rebase to upstream 1.1.0

* Fri Jun  1 2018 Ted Ross <tross@redhat.com> - 1.0.0-6.hotfix.1
- Added ENTMQIC-1997 fix

* Fri Feb  9 2018 Irina Boverman <iboverma@redhat.com> - 1.0.0-6
- Added ENTMQIC-1983 fix

* Tue Jan  2 2018 Irina Boverman <iboverma@redhat.com> - 1.0.0-5
- Added ENTMQIC-1975 fix 

* Mon Nov 20 2017 Irina Boverman <iboverma@redhat.com> - 1.0.0-4
- Added DISPATCH-881 fix

* Fri Nov 17 2017 Irina Boverman <iboverma@redhat.com> - 1.0.0-3
- Rebased to 1.0.0

* Thu Oct 19 2017 Irina Boverman <iboverma@redhat.com> - 1.0.0-2
- Rebased to 1.0.0 rc1
- Added licenses.xml file

* Thu Jul 20 2017 ike Cressman <mcressma@redhat.com> - 0.8.0-10
- Resolves: BZ-1417303/ENTMQIC-1943, BZ-1426242/ENTMQIC-1942

* Thu Apr 27 2017 Irina Boverman <iboverma@redhat.com> - 0.8.0-9
- Resolves: ENTMQIC-1937

* Tue Apr 18 2017 Irina Boverman <iboverma@redhat.com> - 0.8.0-8
- Resolves: ENTMQIC-1931, ENTMQIC-1932

* Thu Mar 16 2017 Irina Boverman <iboverma@redhat.com> - 0.8.0-7
- Resolves: ENTMQIC-77, ENTMQIC-1919, ENTMQIC-1928

* Thu Mar  9 2017 Irina Boverman <iboverma@redhat.com> - 0.8.0-6
- Resolves: ENTMQIC-1922

* Tue Feb  7 2017 Irina Boverman <iboverma@redhat.com> - 0.8.0-5
- Resolves: ENTMQIC-1906, ENTMQIC-1913, ENTMQIC-1914, ENTMQIC-1915,
  ENTMQIC-1916, ENTMQIC-1917, ENTMQIC-1918

* Fri Jan  6 2017 Irina Boverman <iboverma@redhat.com> - 0.8.0-2
- Rebased to amq-beta2 source

* Wed Nov 23 2016 Irina Boverman <iboverma@redhat.com> - 0.8.0-1
- Rebased to amq-beta2-prerelease source

* Thu Nov  3 2016 Irina Boverman <iboverma@redhat.com> - 0.7.0-2
- Rebased to 0.7.0 rc2
- Corrected location of man pages

* Tue Oct  4 2016 Irina Boverman <iboverma@redhat.com> - 0.7.0-1
- Rebased to 0.7.0 rc1

* Wed Sep  7 2016 Irina Boverman <iboverma@redhat.com> - 0.6.1-1
- Rebased to 0.6.1
- Added fix for ENTMQIC-1893

* Tue Aug 30 2016 Irina Boverman <iboverma@redhat.com> - 0.6.0-7
- Rebuilt against proton 0.14.0
- Obsoleted libqpid-dispatch-devel 

* Fri Jun 17 2016 Irina Boverman <iboverma@redhat.com> - 0.6.0-6
- Replaced "Provides" with "Obsoletes"

* Thu Jun 16 2016 Irina Boverman <iboverma@redhat.com> - 0.6.0-5
- Rebased to 0.6.0 ga
- Resolves: DISPATCH-341, DISPATCH-364, DISPATCH-365, DISPATCH-366, DISPATCH-387

* Thu Jun  2 2016 Irina Boverman <iboverma@redhat.com> - 0.6.0-4
- Rebased to 0.6.0 rc4
- Changed qpid-dispatch-router-docs to qpid-dispatch-docs

* Wed May 18 2016 Irina Boverman <iboverma@redhat.com> - 0.6.0-3
- Rebased to 0.6.0 rc3

* Tue May 17 2016 Irina Boverman <iboverma@redhat.com> - 0.6.0-2
- Rebased to 0.6.0 rc2
- Moved content of libqpid-dispatch package to the router 
- Removed libqpid-dispatch-devel package
- Removed include files

* Fri Apr 15 2016 Irina Boverman <iboverma@redhat.com> - 0.6.0-1
- Rebased to 0.6 Beta

* Wed Nov 18 2015 Ted Ross <tross@redhat.com> - 0.4-11
- Resolved: Bug 1281947 - qdrouterd not responding in Satellite6

* Tue Sep 29 2015 Ted Ross <tross@redhat.com> - 0.4-10
- Resolved: Bug 1264509 - qdrouterd utilizes 120-150% cpu time
- Resolved: Bug 1267156 - qdrouterd segfaults in pni_record_find

* Thu Sep 24 2015 Ted Ross <tross@redhat.com> - 0.4-9
- Resolved: ENTMQ-1149 - Memory leak when connecting a SSL client in a loop
- Resolved: DISPATCH-144 - Configurable heartbeats for listeners and connectors

* Wed Aug 5 2015 Ted Ross <tross@redhat.com> - 0.4-8
- Resolved: Bug 1246263 - A compromised content host can execute arbitrary code on sat6 server and send commands to all other content hosts

* Wed Jun 3 2015 Ted Ross <tross@redhat.com> - 0.4-7
- Resolved: Bug 1225210 - qdrouterd core dumped while syncing multiple capsules

* Tue May 12 2015 Ted Ross <tross@redhat.com> - 0.4-6
- Respin to cover all architectures.

* Mon May 11 2015 Ted Ross <tross@redhat.com> - 0.4-5
- Resolved: ENTMQ-1006 - Cannot synchronize routers with a star topology containing 20 leaf nodes

* Mon Apr 13 2015 Ted Ross <tross@redhat.com> - 0.4-4
- Fixed a RHEL6-install problem (run directory not created)

* Fri Apr 10 2015 Irina Boverman <iboverma@redhat.com> - 0.4-3
- Rebased to released 0.4 upstream
- Resolved: 1201027, DISPATCH-133

* Thu Apr  2 2015 Irina Boverman <iboverma@redhat.com> - 0.4-2.20150402
- Rebased to upstream snapshot 1670954

* Mon Feb 23 2015 Ted Ross <tross@redhat.com> - 0.4-2.20150223
- Fixed issues discovered by rpmdiff

* Thu Feb 19 2015 Ted Ross <tross@redhat.com> - 0.4-2.20150219
- Rebased to upstream snapshot 1661010

* Wed Feb 18 2015 Irina Boverman <iboverma@redhat.com> - 0.4-2.20150218
- Rebased to upstream snapshot 1660738 (Last Changed Rev: 1660734)

* Fri Feb 13 2015 Ted Ross <tross@redhat.com> - 0.4-2.20150213
- Rebased to upstream snapshot 1659335

* Tue Feb 10 2015 Irina Boverman <iboverma@redhat.com> - 0.4-2.20150210
- Rebased to upstream trunk branch 2015-02-09 snapshot

* Tue Jan 27 2015 Darryl L. Pierce <dpierce@redhat.com> - 0.3-1
- Rebased on Dispatch 0.3.
- Increased the minimum Proton version needed to 0.8.
- Moved all tests to the -devel package.
- Ensure executable bit turned off on systemd file.
- Set the location of installed documentation.

* Thu Nov 20 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-9
- Fixed a merge issue that resulted in two patches not being applied.
- Resolves: BZ#1165691

* Wed Nov 19 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-8
- DISPATCH-75 - Removed reference to qdstat.conf from qdstat manpage.
- Include systemd service file for EPEL7 packages.
- Brought systemd support up to current Fedora packaging guidelines.
- Resolves: BZ#1165691
- Resolves: BZ#1165681

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Jul  9 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-6
- Removed intro-package comments which can cause POSTUN warnings.
- Added dependency on libqpid-dispatch from qpid-dispatch-tools.

* Wed Jul  2 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-5
- Fixed the path for the configuration file.
- Resolves: BZ#1115416

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 30 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-3
- Fixed build type to be RelWithDebInfo

* Tue Apr 22 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2
- Fixed merging problems across Fedora and EPEL releases.

* Tue Apr 22 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-1
- Rebased on Qpid Dispatch 0.2.

* Wed Feb  5 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-4
- Fixed path to configuration in qpid-dispatch.service file.
- Added requires from qpid-dispatch-tools to python-qpid-proton.

* Thu Jan 30 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-3
- Fix build system to not discard CFLAGS provided by Fedora
- Resolves: BZ#1058448
- Simplified the specfile to be used across release targets.

* Fri Jan 24 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-2
- First release for Fedora.
- Resolves: BZ#1055721

* Thu Jan 23 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-1.2
- Put all subpackage sections above prep/build/install.
- Removed check and clean sections.
- Added remaining systemd macros.
- Made qpid-dispatch-router-docs a noarch package.
* Wed Jan 22 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-1.1
- Added the systemd macros for post/preun/postun
- Moved prep/build/install/check/clean above package definitions.

* Mon Jan 20 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-1
- Initial packaging of the codebase.
